summaryrefslogtreecommitdiffstats
path: root/libksieve
diff options
context:
space:
mode:
Diffstat (limited to 'libksieve')
-rw-r--r--libksieve/parser/lexer.cpp4
-rw-r--r--libksieve/tests/lexertest.cpp6
-rw-r--r--libksieve/tests/parsertest.cpp6
3 files changed, 8 insertions, 8 deletions
diff --git a/libksieve/tests/lexertest.cpp b/libksieve/tests/lexertest.cpp
index dee04bd1..df5ac6e1 100644
--- a/libksieve/tests/lexertest.cpp
+++ b/libksieve/tests/lexertest.cpp
@@ -37,7 +37,7 @@ using KSieve::Lexer;
#include <ksieve/error.h>
using KSieve::Error;
-#include <tqcstring.h> // qstrlen
+#include <tqcstring.h> // tqstrlen
#include <tqstring.h>
#include <iostream>
@@ -398,7 +398,7 @@ int main( int argc, char * argv[] ) {
if ( argc == 2 ) { // manual test
const char * scursor = argv[1];
- const char * const send = argv[1] + qstrlen( argv[1] );
+ const char * const send = argv[1] + tqstrlen( argv[1] );
Lexer lexer( scursor, send );
@@ -424,7 +424,7 @@ int main( int argc, char * argv[] ) {
for ( int i = 0 ; i < numTestCases ; ++i ) {
bool ok = true;
const TestCase & t = testcases[i];
- const char * const send = t.string + qstrlen( t.string );
+ const char * const send = t.string + tqstrlen( t.string );
Lexer lexer( t.string, send, Lexer::IncludeComments );
cerr << t.name << ":";
for ( int j = 0 ; !lexer.atEnd() ; ++j ) {
diff --git a/libksieve/tests/parsertest.cpp b/libksieve/tests/parsertest.cpp
index fdc08a97..9d0d8e14 100644
--- a/libksieve/tests/parsertest.cpp
+++ b/libksieve/tests/parsertest.cpp
@@ -37,7 +37,7 @@ using KSieve::Parser;
#include <ksieve/error.h>
#include <ksieve/scriptbuilder.h>
-#include <tqcstring.h> // qstrlen
+#include <tqcstring.h> // tqstrlen
#include <tqstring.h>
#include <iostream>
@@ -627,7 +627,7 @@ int main( int argc, char * argv[] ) {
if ( argc == 2 ) { // manual test
const char * scursor = argv[1];
- const char * const send = argv[1] + qstrlen( argv[1] );
+ const char * const send = argv[1] + tqstrlen( argv[1] );
Parser parser( scursor, send );
PrintingScriptBuilder psb;
@@ -644,7 +644,7 @@ int main( int argc, char * argv[] ) {
const TestCase & t = testCases[i];
cerr << t.name << ":";
VerifyingScriptBuilder v( t );
- Parser p( t.script, t.script + qstrlen( t.script ) );
+ Parser p( t.script, t.script + tqstrlen( t.script ) );
p.setScriptBuilder( &v );
const bool ok = p.parse();
if ( v.ok() )
diff --git a/libksieve/parser/lexer.cpp b/libksieve/parser/lexer.cpp
index c0b7cb8b..be0c493f 100644
--- a/libksieve/parser/lexer.cpp
+++ b/libksieve/parser/lexer.cpp
@@ -476,9 +476,9 @@ namespace KSieve {
const int identifierLength = mState.cursor - identifierStart;
// Can use the fast fromLatin1 here, since identifiers are always
// in the us-ascii subset:
- result += TQString::fromLatin1( identifierStart, identifierLength );
+ result += TQString::tqfromLatin1( identifierStart, identifierLength );
if ( atEnd() || isDelim( *mState.cursor ) )
return true;
@@ -476,9 +476,9 @@ namespace KSieve {
const int identifierLength = mState.cursor - identifierStart;
- // Can use the fast fromLatin1 here, since identifiers are always
+ // Can use the fast tqfromLatin1 here, since identifiers are always
// in the us-ascii subset: